package com.hbzh.sdkexample;

import android.app.Fragment;
import android.app.ProgressDialog;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.hanbang.netsdk.HBNetCtrl;
import com.hanbang.ydtsdk.YdtDeviceInfo;
import com.hanbang.ydtsdk.YdtDeviceParam;
import com.hanbang.ydtsdk.YdtNetSDK;
import com.hanbang.ydtsdk.YdtSdkError;

/**
 * Created by Administrator on 2016/4/13.
 */
public class DeviceDomainFragment extends Fragment {

    private EditText editDomain;
    private EditText editPort;
    private EditText editUser;
    private EditText editPassword;

    private ProgressDialog progressDialog;

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_device_domain, container, false);

        editDomain = (EditText)view.findViewById(R.id.edit_domain);
        editPort = (EditText)view.findViewById(R.id.edit_port);
        editUser = (EditText)view.findViewById(R.id.edit_user);
        editPassword = (EditText)view.findViewById(R.id.edit_password);

        ((Button)view.findViewById(R.id.btn_add)).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //读取参数
                String devDomain = editDomain.getText().toString();
                if (devDomain.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入域名", Toast.LENGTH_LONG).show();
                    return;
                }

                String devPort = editPort.getText().toString();
                if (devPort.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入端口", Toast.LENGTH_LONG).show();
                    return;
                }

                String devUser = editUser.getText().toString();
                if (devUser.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入设备的用户名", Toast.LENGTH_LONG).show();
                    return;
                }

                String devPsw = editPassword.getText().toString();
                if (devPsw.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入设备的密码", Toast.LENGTH_LONG).show();
                    return;
                }

                int port = Integer.parseInt(devPort);
                addDeviceByDomain(devDomain, port, devUser, devPsw);
            }
        });
        return view;
    }

    private void addDeviceByDomain(final String domain, final int port, final String user, final String password)
    {
        //弹出进度提示框
        progressDialog = ProgressDialog.show(getActivity(), "", "正在添加...", false);

        //由于网络处理比较耗时，需另起线程处理
        new Thread(new Runnable() {
            @Override
            public void run() {
                //区分是局域网Ip还是域名
                DeviceInfo deviceInfo = new DeviceInfo();
                if (domain.matches("((25[0-5])|(2[0-4]\\d)|(1\\d\\d)|([1-9]\\d)|\\d)(.((25[0-5])|(2[0-4]\\d)|(1\\d\\d)|([1-9]\\d)|\\d)){3}"))
                {
                    //IP
                    deviceInfo.deviceLanIp = domain;
                    deviceInfo.deviceLanPort = port;
                }
                else
                {
                    //域名
                    deviceInfo.deviceDomain = domain;
                    deviceInfo.domainPort = port;
                }

                deviceInfo.deviceUser = user;
                deviceInfo.devicePsw = password;
                deviceInfo.hbNetCtrl = new HBNetCtrl();

                //登录设备
                int result = deviceInfo.hbNetCtrl.login(user, password, domain, port, deviceInfo.callback);

                String message = "";
                if (0 != result)
                {
                    //登录失败，不允许添加该设备
                    message = "添加设备失败";
                }
                else
                {
                    //登录成功
                    deviceInfo.isOnline = true;

                    //获取序列号等信息
                    deviceInfo.deviceSn = deviceInfo.hbNetCtrl.getSerialNo();
                    deviceInfo.deviceName = deviceInfo.hbNetCtrl.getDeviceName();
                    deviceInfo.channelCount = deviceInfo.hbNetCtrl.getChannelCount();

                    //获取设备信息
                    YdtNetSDK ydtNetSDK = AccountInfo.getInstance().getYdtNetSDK();
                    YdtDeviceInfo ydtDeviceInfo = ydtNetSDK.getSpecifiedDeviceWithoutLogin(deviceInfo.deviceSn);
                    if (0 != ydtDeviceInfo.nErrorCode)
                    {
                        //获取设备信息失败，不允许添加
                        message = "添加设备失败：" + YdtSdkError.getErrorMessage(getActivity(), ydtDeviceInfo.nErrorCode);

                        //注销设备
                        deviceInfo.hbNetCtrl.logout();
                        deviceInfo.isOnline = false;
                    }
                    else
                    {
                        //记录vvid等信息
                        YdtDeviceParam ydtDeviceParam = ydtDeviceInfo.deviceList.get(0);
                        deviceInfo.vveyeId = ydtDeviceParam.devVNIp;
                        deviceInfo.vveyeRemortPort = ydtDeviceParam.devVNPort;
                        deviceInfo.deviceId = ydtDeviceParam.devId;

                        //通过域名添加设备
                        YdtDeviceInfo curDeviceInfo = null;
                        if (deviceInfo.deviceDomain.isEmpty() || 0 == deviceInfo.domainPort)
                        {
                            //如果是局域网IP，则使用序列号添加
                            curDeviceInfo = ydtNetSDK.addDeviceBySN(deviceInfo.deviceId,
                                    deviceInfo.deviceName, deviceInfo.deviceUser,
                                    deviceInfo.devicePsw, deviceInfo.channelCount);
                        }
                        else
                        {
                            curDeviceInfo = ydtNetSDK.addDeviceByDomain(deviceInfo.deviceSn,
                                    deviceInfo.deviceName, deviceInfo.deviceUser,
                                    deviceInfo.devicePsw, deviceInfo.deviceDomain,
                                    deviceInfo.domainPort, deviceInfo.channelCount);
                        }

                        if (null == curDeviceInfo || 0 != curDeviceInfo.nErrorCode)
                        {
                            //添加失败
                            message = "添加设备失败：" + YdtSdkError.getErrorMessage(getActivity(), curDeviceInfo.nErrorCode);

                            //注销设备
                            deviceInfo.hbNetCtrl.logout();
                            deviceInfo.isOnline = false;
                        }
                        else
                        {
                            message = "添加成功";
                            AccountInfo.getInstance().addDeviceToList(deviceInfo);
                        }
                    }
                }

                final String tipInfo = message;
                editPort.post(new Runnable() {
                    @Override
                    public void run() {
                        progressDialog.dismiss();
                        Toast.makeText(getActivity(), tipInfo, Toast.LENGTH_LONG).show();
                    }
                });
            }
        }).start();
    }
}
