package com.hbzh.sdkexample;

import android.app.Fragment;
import android.app.ProgressDialog;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.hanbang.netsdk.HBNetCtrl;
import com.hanbang.netsdk.NetParamDef;
import com.hanbang.ydtsdk.YdtDeviceInfo;
import com.hanbang.ydtsdk.YdtDeviceParam;
import com.hanbang.ydtsdk.YdtNetSDK;
import com.hanbang.ydtsdk.YdtSdkError;


public class DeviceSnFragment extends Fragment {

    private EditText editDevSn;
    private EditText editDevUser;
    private EditText editDevPsw;

    private ProgressDialog progressDialog;

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        View view = inflater.inflate(R.layout.fragment_device_sn, container, false);

        editDevSn = (EditText)view.findViewById(R.id.edit_sn);
        editDevUser = (EditText)view.findViewById(R.id.edit_user);
        editDevPsw = (EditText)view.findViewById(R.id.edit_password);

        //添加
        ((Button)view.findViewById(R.id.btn_add)).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //读取参数
                String devSn = editDevSn.getText().toString();
                if (devSn.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入序列号", Toast.LENGTH_LONG).show();
                    return;
                }

                String devUser = editDevUser.getText().toString();
                if (devUser.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入设备的用户名", Toast.LENGTH_LONG).show();
                    return;
                }

                String devPsw = editDevPsw.getText().toString();
                if (devPsw.isEmpty()) {
                    Toast.makeText(getActivity(), "请输入设备的密码", Toast.LENGTH_LONG).show();
                    return;
                }

                addDeviceBySn(devSn, devUser, devPsw);
            }
        });
        return view;
    }

    private void addDeviceBySn(final String devSn, final String user, final String password)
    {
        //弹出进度提示框
        progressDialog = ProgressDialog.show(getActivity(), "", "正在添加...", false);

        //由于网络处理比较耗时，需另起线程处理
        new Thread(new Runnable() {
            @Override
            public void run() {
                //向帐户下添加设备
                //注意，这里使用的YdtNetSDK对象，必须跟登录帐户使用的是同一个。
                YdtNetSDK ydtNetSDK = AccountInfo.getInstance().getYdtNetSDK();

                //获取设备信息
                final YdtDeviceInfo deviceInfo = ydtNetSDK.getSpecifiedDeviceWithoutLogin(devSn);
                if (0 != deviceInfo.nErrorCode)
                {
                    //获取设备信息失败，无法继续添加
                    progressDialog.dismiss();

                    editDevPsw.post(new Runnable() {
                        @Override
                        public void run() {
                            String message = YdtSdkError.getErrorMessage(getActivity(), deviceInfo.nErrorCode);
                            Toast.makeText(getActivity(), "添加设备失败：" + message, Toast.LENGTH_LONG).show();
                        }
                    });
                }
                else
                {
                    //记录设备信息
                    YdtDeviceParam deviceParam = deviceInfo.deviceList.get(0);
                    DeviceInfo devInfo = new DeviceInfo();
                    devInfo.deviceUser = user;
                    devInfo.devicePsw = password;
                    devInfo.deviceSn = devSn;
                    devInfo.deviceId = deviceParam.devId;
                    devInfo.deviceName = deviceParam.devName;
                    devInfo.deviceDomain = deviceParam.devDomain;
                    devInfo.domainPort = deviceParam.devDomainPort;
                    devInfo.vveyeId = deviceParam.devVNIp;
                    devInfo.vveyeRemortPort = deviceParam.devVNPort;
                    devInfo.channelCount = deviceParam.devChannelCount;

                    //登录设备
                    devInfo.hbNetCtrl = new HBNetCtrl();
                    final int result = loginDevice(devInfo);

                    if (0 != result)
                    {
                        //登录设备失败，不允许添加设备
                        progressDialog.dismiss();
                        editDevPsw.post(new Runnable() {
                            @Override
                            public void run() {
                                Toast.makeText(getActivity(), "添加设备失败", Toast.LENGTH_LONG).show();
                            }
                        });
                    }
                    else
                    {
                        final YdtDeviceInfo curDevInfo = ydtNetSDK.addDeviceBySN(devInfo.deviceId,
                                devInfo.deviceName,
                                devInfo.deviceUser,
                                devInfo.devicePsw,
                                devInfo.channelCount);

                        if (0 != curDevInfo.nErrorCode)
                        {
                            //添加失败，注销设备
                            devInfo.hbNetCtrl.logout();
                            devInfo.isOnline = false;
                            devInfo = null;
                        }
                        else
                        {
                            //添加成功
                            AccountInfo.getInstance().addDeviceToList(devInfo);
                        }

                        editDevPsw.post(new Runnable() {
                            @Override
                            public void run() {
                                progressDialog.dismiss();

                                String message = "添加成功";
                                if (0 != curDevInfo.nErrorCode)
                                {
                                    message = "添加设备失败：" + YdtSdkError.getErrorMessage(getActivity(), curDevInfo.nErrorCode);
                                }
                                Toast.makeText(getActivity(),  message, Toast.LENGTH_LONG).show();
                            }
                        });

                    }
                }
            }
        }).start();
    }

    /**
     * 登录设备
     * @param device
     *      设备信息。
     * @return
     *      成功返回0，其他为失败。
     */
    private int loginDevice(DeviceInfo device)
    {
        int result = -1;

        //vv登录
        if (!device.vveyeId.isEmpty() && 0 != device.vveyeRemortPort)
        {
            result = device.hbNetCtrl.loginVveye(device.deviceUser,
                    device.devicePsw, device.vveyeId,
                    device.vveyeRemortPort, device.callback);
        }


        if (0 != result)
        {
            //vv登录失败，尝试域名登录
            if (!device.deviceDomain.isEmpty() && 0 != device.domainPort)
            {
                result = device.hbNetCtrl.login(device.deviceUser,
                        device.devicePsw, device.deviceDomain,
                        device.domainPort, device.callback);
            }
        }

        //判断登录结果
        if (0 == result)
        {
            //检验序列号是否匹配，以保证不会串设备
            if (device.deviceSn.equals(device.hbNetCtrl.getSerialNo()))
            {
                device.isOnline = true;
                result = 0;
            }
            else
            {
                //MAC地址不匹配
                result = -1;
            }
        }

        return result;
    }
}
