package com.hbzh.sdkexample.login;

import android.app.ProgressDialog;
import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.hanbang.ydtsdk.YdtNetSDK;
import com.hanbang.ydtsdk.YdtSdkError;
import com.hanbang.ydtsdk.YdtUserInfo;
import com.hbzh.sdkexample.AccountInfo;
import com.hbzh.sdkexample.MainActivity;
import com.hbzh.sdkexample.R;

public class LoginActivity extends AppCompatActivity
{

    /**
     * 用户名输入框
     */
    EditText mUserNameText;

    /**
     * 密码输入框
     */
    EditText mPassWordText;

    /**
     * 登录按钮
     */
    Button mLoginBtn;

    /**
     * 找回密码按钮
     */
    Button mFindPWBtn;

    //获取用户信息按钮
    Button getAIBtn;

    /**
     * 注册按钮
     */
    Button mRegisterBtn;

    /**
     * 显示登录状态
     */
    TextView mLoginStatus;

    /**
     * 一点通网络库
     */
    YdtNetSDK mYdtNetSDK;

    ProgressDialog dialog;

    /**
     * 是否登录
     */
    boolean isLogin = false;


    @Override
    protected void onCreate( Bundle savedInstanceState )
    {
        super.onCreate( savedInstanceState );
        setContentView( R.layout.activity_login );

        mYdtNetSDK = AccountInfo.getInstance().getYdtNetSDK();

        initView();
    }

    /**
     * 初始化界面
     */
    private void initView()
    {
        mLoginBtn = (Button) findViewById( R.id.login_btn );
        mFindPWBtn = (Button) findViewById( R.id.findpw );
        mRegisterBtn = (Button) findViewById( R.id.register );
        mUserNameText = (EditText) findViewById( R.id.user_name );
        mPassWordText = (EditText) findViewById( R.id.password );
        mLoginStatus = (TextView) findViewById( R.id.login_status );
        getAIBtn = (Button) findViewById( R.id.get_account_btn );

        //登录
        mLoginBtn.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                final String userName = mUserNameText.getText().toString();
                final String passWord = mPassWordText.getText().toString();

                if ( "".equals( userName ) || "".equals( passWord ) )
                {
                    return;
                }

                dialog = ProgressDialog.show( LoginActivity.this, "", "正在登陆...", false );

                new Thread( new Runnable()
                {
                    @Override
                    public void run()
                    {
                        //一点通账户登录 userName:用户名；passWord：密码
                        final YdtUserInfo ydtUserInfo = mYdtNetSDK.loginByYdtAccount( userName, passWord, "" );
                        if ( ydtUserInfo.nErrorCode == 0 )
                        {

                            mLoginStatus.post( new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    isLogin = true;
                                    dialog.dismiss();
                                    mLoginStatus.setText( "登录成功" );
                                }
                            } );
                        }
                        else
                        {
                            mLoginStatus.post( new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    dialog.dismiss();
                                    mLoginStatus.setText( "登录失败，错误码为：" + ydtUserInfo.nErrorCode );
                                }
                            } );
                        }
                    }
                } ).start();
            }
        } );

        //找回密码
        mFindPWBtn.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                Intent intent = new Intent( LoginActivity.this, FindPassWordActivity.class );
                startActivity( intent );
            }
        } );

        //注册用户
        mRegisterBtn.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                Intent intent = new Intent( LoginActivity.this, RegisterActivity.class );
                startActivity( intent );
            }
        } );

        //退出账户
        Button logoutBtn = (Button) findViewById( R.id.logout_btn );
        logoutBtn.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                if ( !isLogin )
                {
                    Toast.makeText( LoginActivity.this, "请先登录！", Toast.LENGTH_SHORT ).show();
                    return;
                }
                dialog.show();
                new Thread( new Runnable()
                {
                    @Override
                    public void run()
                    {
                        mYdtNetSDK.logoutYdt();
                        mLoginStatus.post( new Runnable()
                        {
                            @Override
                            public void run()
                            {
                                isLogin = false;
                                mLoginStatus.setText( "退出成功" );
                                dialog.dismiss();
                            }
                        } );
                    }
                } ).start();

            }
        } );

        /**
         * 获取用户信息
         */
        getAIBtn.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                new Thread( new Runnable()
                {
                    @Override
                    public void run()
                    {
                        //userName：用户名/手机号/邮箱
                        final String userName = mUserNameText.getText().toString();
                        if ( "".equals( userName ) )
                        {
                            return;
                        }
                        final YdtUserInfo ydtUserInfo = mYdtNetSDK.getAccountInfo( userName );
                        getAIBtn.post( new Runnable()
                        {
                            @Override
                            public void run()
                            {
                                if ( YdtSdkError.ERR_SUCCESS == ydtUserInfo.nErrorCode )
                                {
                                    Toast.makeText( LoginActivity.this,"获取用户信息成功！",Toast.LENGTH_SHORT ).show();
                                }
                                else
                                {
                                    Toast.makeText( LoginActivity.this,"获取用户信息失败！",Toast.LENGTH_SHORT ).show();
                                }
                            }
                        } );
                    }
                } ).start();
            }
        } );

        //跳转到设备
        Button getDevice = (Button) findViewById( R.id.go_device_btn );
        getDevice.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                if ( !isLogin )
                {
                    Toast.makeText( LoginActivity.this, "请先登录！", Toast.LENGTH_SHORT ).show();
                    return;
                }
                Intent intent = new Intent( LoginActivity.this, MainActivity.class );
                startActivity( intent );
            }
        } );
    }
}
