package com.hbzh.sdkexample.login;

import android.app.ProgressDialog;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.hanbang.ydtsdk.YdtCheckCodeInfo;
import com.hanbang.ydtsdk.YdtNetSDK;
import com.hanbang.ydtsdk.YdtSdkError;
import com.hanbang.ydtsdk.YdtUserInfo;
import com.hbzh.sdkexample.AccountInfo;
import com.hbzh.sdkexample.R;

import java.util.Locale;

public class RegisterActivity extends AppCompatActivity
{
    /**
     * 手机号、邮箱、账户名
     */
    EditText mAccount;

    /**
     * 验证码
     */
    EditText mAuthcode;

    /**
     * 输入新的密码
     */
    EditText mPassWord;

    /**
     * 获取验证码按钮
     */
    Button mGetAuthcode;

    /**
     * 确定按钮
     */
    Button mFinish;

    private String mAccountName = "";                    //账户名（手机号、邮箱）

    private String mSendtoAddr = "";                    //验证码发往

    ProgressDialog dialog;

    @Override
    protected void onCreate( Bundle savedInstanceState )
    {
        super.onCreate( savedInstanceState );
        setContentView( R.layout.activity_register );

        initView();
    }

    private void initView()
    {
        mAccount = (EditText) findViewById( R.id.account_name );
        mAuthcode = (EditText) findViewById( R.id.text_authcode );
        mPassWord = (EditText) findViewById( R.id.text_password );
        mGetAuthcode = (Button) findViewById( R.id.get_authcode );
        mFinish = (Button) findViewById( R.id.register__btn );

        //获取验证码
        mGetAuthcode.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {

                mAccountName = mAccount.getText().toString();
                if ( "".equals( mAccountName ) )
                {
                    Toast.makeText( RegisterActivity.this, "请输入正确的手机号、用户名、邮箱", Toast.LENGTH_SHORT ).show();
                    return;
                }
                new Thread( new Runnable()
                {
                    @Override
                    public void run()
                    {

                        //先获取一次用户信息，看用户是否存在
                        YdtNetSDK ydtNetSDK = AccountInfo.getInstance().getYdtNetSDK();
                        YdtUserInfo userInfo = ydtNetSDK.getAccountInfo( mAccountName );
                        if ( 0 == userInfo.nErrorCode )
                        {
                            mGetAuthcode.post( new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    Toast.makeText( RegisterActivity.this,"用户已经注册",Toast.LENGTH_SHORT ).show();
                                }
                            } );
                        }
                        else
                        {
                            mSendtoAddr = mAccountName;

                            String language = "zh_CN";
                            if (!Locale.getDefault().toString().equals(language))
                            {
                                language = "en_US";
                            }

                            YdtCheckCodeInfo info = ydtNetSDK.getMessageCheckCode(mSendtoAddr, language);
                            handleGetAuthcoeResult( info.nErrorCode, info.nRecvAddrType);
                        }
                    }
                } ).start();

            }
        } );

        //确定按钮
        mFinish.setOnClickListener( new View.OnClickListener()
        {
            @Override
            public void onClick( View v )
            {
                final String passWord = mPassWord.getText().toString();
                if ( passWord.length() < 6 )
                {
                    //密码长度在6~15位之间
                    Toast.makeText( RegisterActivity.this, "请输入6位以上的密码", Toast.LENGTH_SHORT ).show();
                    return;
                }

                dialog = ProgressDialog.show( RegisterActivity.this, "", "请稍等...", false );

                //认证验证码,设置密码
                new Thread( new Runnable()
                {
                    @Override
                    public void run()
                    {
                        // TODO Auto-generated method stub
                        YdtNetSDK ydtSdk = AccountInfo.getInstance().getYdtNetSDK();
                        //输入的验证码
                        String mAuthCode = mAuthcode.getText().toString();

                        //认证验证码
                        YdtUserInfo userInfo = ydtSdk.registerCheckAndLogin( mSendtoAddr, mAuthCode, "" );
                        if ( 0 == userInfo.nErrorCode )
                        {
                            //设置密码
                            final int error = ydtSdk.setPassword( passWord );

                            mAuthcode.post( new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    if ( 0 == error )
                                    {
                                        Toast.makeText( RegisterActivity.this, "设置密码成功", Toast.LENGTH_LONG ).show();
                                    }
                                    else
                                    {
                                        Toast.makeText( RegisterActivity.this, "设置密码失败", Toast.LENGTH_LONG ).show();
                                    }
                                    dialog.dismiss();
                                }
                            } );

                        }
                        else
                        {
                            mAuthcode.post( new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    Toast.makeText( RegisterActivity.this, "认证验证码失败", Toast.LENGTH_LONG ).show();
                                    dialog.dismiss();
                                }
                            } );

                        }

                    }
                } ).start();
            }
        } );

    }


    /**
     * 接收处理
     *
     * @param error
     * @param sendTo
     */
    private void handleGetAuthcoeResult( final int error, final int sendTo )
    {
        mGetAuthcode.post( new Runnable()
        {

            @Override
            public void run()
            {
                // TODO Auto-generated method stub
                StringBuilder tipText = new StringBuilder();
                if ( YdtSdkError.ERR_SUCCESS == error )
                {
                    if ( 1 == sendTo )
                    {
                        tipText.append( "验证码发往手机" );
                        tipText.append( mSendtoAddr );
                    }
                    else if ( 2 == sendTo )
                    {
                        tipText.append( "验证码发往邮箱" );
                        tipText.append( mSendtoAddr );
                    }
                }
                else
                {
                    tipText.append( "错误码" + error );
                }
                Toast.makeText( RegisterActivity.this, tipText, Toast.LENGTH_LONG ).show();
            }
        } );
    }
}
